Struct Uri
pub struct Uri {
scheme: Scheme,
authority: Authority,
path_and_query: PathAndQuery,
}Expand description
The URI component of a request.
For HTTP 1, this is included as part of the request line. From Section 5.3, Request Target:
Once an inbound connection is obtained, the client sends an HTTP request message (Section 3) with a request-target derived from the target URI. There are four distinct formats for the request-target, depending on both the method being requested and whether the request is to a proxy.
request-target = origin-form / absolute-form / authority-form / asterisk-form
The URI is structured as follows:
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-| |-------------------------------||--------| |-------------------| |-----|
| | | | |
scheme authority path query fragmentFor HTTP 2.0, the URI is encoded using pseudoheaders.
Examples
use http::Uri;
let uri = "/foo/bar?baz".parse::<Uri>().unwrap();
assert_eq!(uri.path(), "/foo/bar");
assert_eq!(uri.query(), Some("baz"));
assert_eq!(uri.host(), None);
let uri = "https://www.rust-lang.org/install.html".parse::<Uri>().unwrap();
assert_eq!(uri.scheme_str(), Some("https"));
assert_eq!(uri.host(), Some("www.rust-lang.org"));
assert_eq!(uri.path(), "/install.html");Fields
scheme: Schemepath_and_query: PathAndQueryImplementations
impl Uri
impl Uri
pub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture a Uri.
This method returns an instance of Builder which can be usd to
create a Uri.
Examples
use http::Uri;
let uri = Uri::builder()
.scheme("https")
.authority("hyper.rs")
.path_and_query("/")
.build()
.unwrap();pub fn from_parts(src: Parts) -> Result<Uri, InvalidUriParts>
pub fn from_parts(src: Parts) -> Result<Uri, InvalidUriParts>
Attempt to convert a Parts into a Uri.
Examples
Relative URI
let mut parts = Parts::default();
parts.path_and_query = Some("/foo".parse().unwrap());
let uri = Uri::from_parts(parts).unwrap();
assert_eq!(uri.path(), "/foo");
assert!(uri.scheme().is_none());
assert!(uri.authority().is_none());Absolute URI
let mut parts = Parts::default();
parts.scheme = Some("http".parse().unwrap());
parts.authority = Some("foo.com".parse().unwrap());
parts.path_and_query = Some("/foo".parse().unwrap());
let uri = Uri::from_parts(parts).unwrap();
assert_eq!(uri.scheme().unwrap().as_str(), "http");
assert_eq!(uri.authority().unwrap(), "foo.com");
assert_eq!(uri.path(), "/foo");Attempt to convert a Bytes buffer to a Uri.
This will try to prevent a copy if the type passed is the type used internally, and will copy the data if it is not.
pub fn from_static(src: &'static str) -> Uri
pub fn from_static(src: &'static str) -> Uri
Convert a Uri from a static string.
This function will not perform any copying, however the string is checked to ensure that it is valid.
Panics
This function panics if the argument is an invalid URI.
Examples
let uri = Uri::from_static("http://example.com/foo");
assert_eq!(uri.host().unwrap(), "example.com");
assert_eq!(uri.path(), "/foo");pub fn into_parts(self) -> Parts
pub fn into_parts(self) -> Parts
Convert a Uri into Parts.
Note
This is just an inherent method providing the same functionality as
let parts: Parts = uri.into()
Examples
let uri: Uri = "/foo".parse().unwrap();
let parts = uri.into_parts();
assert_eq!(parts.path_and_query.unwrap(), "/foo");
assert!(parts.scheme.is_none());
assert!(parts.authority.is_none());pub fn path_and_query(&self) -> Option<&PathAndQuery>
pub fn path_and_query(&self) -> Option<&PathAndQuery>
Returns the path & query components of the Uri
pub fn path(&self) -> &str
pub fn path(&self) -> &str
Get the path of this Uri.
Both relative and absolute URIs contain a path component, though it might be the empty string. The path component is case sensitive.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|--------|
|
pathIf the URI is * then the path component is equal to *.
Examples
A relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert_eq!(uri.path(), "/hello/world");An absolute URI
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.path(), "/hello/world");pub fn scheme(&self) -> Option<&Scheme>
pub fn scheme(&self) -> Option<&Scheme>
Get the scheme of this Uri.
The URI scheme refers to a specification for assigning identifiers within that scheme. Only absolute URIs contain a scheme component, but not all absolute URIs will contain a scheme component. Although scheme names are case-insensitive, the canonical form is lowercase.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-|
|
schemeExamples
Absolute URI
use http::uri::{Scheme, Uri};
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.scheme(), Some(&Scheme::HTTP));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.scheme().is_none());pub fn scheme_str(&self) -> Option<&str>
pub fn scheme_str(&self) -> Option<&str>
Get the scheme of this Uri as a &str.
Example
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.scheme_str(), Some("http"));Get the authority of this Uri.
The authority is a hierarchical element for naming authority such that the remainder of the URI is delegated to that authority. For HTTP, the authority consists of the host and port. The host portion of the authority is case-insensitive.
The authority also includes a username:password component, however
the use of this is deprecated and should be avoided.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-------------------------------|
|
authorityExamples
Absolute URI
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.authority().map(|a| a.as_str()), Some("example.org:80"));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.authority().is_none());pub fn host(&self) -> Option<&str>
pub fn host(&self) -> Option<&str>
Get the host of this Uri.
The host subcomponent of authority is identified by an IP literal encapsulated within square brackets, an IPv4 address in dotted- decimal form, or a registered name. The host subcomponent is case-insensitive.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|---------|
|
hostExamples
Absolute URI
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.host(), Some("example.org"));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.host().is_none());pub fn port(&self) -> Option<Port<&str>>
pub fn port(&self) -> Option<Port<&str>>
Get the port part of this Uri.
The port subcomponent of authority is designated by an optional port
number following the host and delimited from it by a single colon (โ:โ)
character. It can be turned into a decimal port number with the as_u16
method or as a str with the as_str method.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-|
|
portExamples
Absolute URI with port
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
let port = uri.port().unwrap();
assert_eq!(port.as_u16(), 80);Absolute URI without port
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert!(uri.port().is_none());Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.port().is_none());pub fn port_u16(&self) -> Option<u16>
pub fn port_u16(&self) -> Option<u16>
Get the port of this Uri as a u16.
Example
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.port_u16(), Some(80));pub fn query(&self) -> Option<&str>
pub fn query(&self) -> Option<&str>
Get the query string of this Uri, starting after the ?.
The query component contains non-hierarchical data that, along with data in the path component, serves to identify a resource within the scope of the URIโs scheme and naming authority (if any). The query component is indicated by the first question mark (โ?โ) character and terminated by a number sign (โ#โ) character or by the end of the URI.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-------------------|
|
queryExamples
Absolute URI
let uri: Uri = "http://example.org/hello/world?key=value".parse().unwrap();
assert_eq!(uri.query(), Some("key=value"));Relative URI with a query string component
let uri: Uri = "/hello/world?key=value&foo=bar".parse().unwrap();
assert_eq!(uri.query(), Some("key=value&foo=bar"));Relative URI without a query string component
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.query().is_none());Trait Implementations
impl From<PathAndQuery> for Uri
Convert a PathAndQuery into a Uri.
impl From<PathAndQuery> for Uri
Convert a PathAndQuery into a Uri.
fn from(path_and_query: PathAndQuery) -> Uri
fn from(path_and_query: PathAndQuery) -> Uri
impl<S> FromRequestParts<S> for Uri
impl<S> FromRequestParts<S> for Uri
type Rejection = Infallible
type Rejection = Infallible
async fn from_request_parts(
parts: &mut Parts,
_: &S,
) -> Result<Uri, <Uri as FromRequestParts<S>>::Rejection>
async fn from_request_parts( parts: &mut Parts, _: &S, ) -> Result<Uri, <Uri as FromRequestParts<S>>::Rejection>
impl FromStr for Uri
impl FromStr for Uri
type Err = InvalidUri
type Err = InvalidUri
impl IntoClientRequest for &Uri
impl IntoClientRequest for &Uri
fn into_client_request(self) -> Result<Request<()>, Error>
fn into_client_request(self) -> Result<Request<()>, Error>
Request that can be used for a client connection.impl IntoClientRequest for Uri
impl IntoClientRequest for Uri
fn into_client_request(self) -> Result<Request<()>, Error>
fn into_client_request(self) -> Result<Request<()>, Error>
Request that can be used for a client connection.impl Eq for Uri